@@ -105,12 +105,9 @@ where
                                 let _ = ws.close(None).await;
                                 return;
                             }
-                        } else {
-                            debug!("responded to server socket");
-                            if chan.send(Ok(())).is_err() {
-                                let _ = ws.close(None).await;
-                                return;
-                            }
+                        } else if chan.send(Ok(())).is_err() {
+                            let _ = ws.close(None).await;
+                            return;
                         }
                     }
                     // If we get *anything*, it means that either the channel is closed
